resultSetStore.SimpleResultSetStore

|  | ## Cheshire3 Object Model: Class SimpleResultSetStore

Module resultSetStore :: Class SimpleResultSetStore

## Class SimpleResultSetStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
       baseObjects.ResultSetStore --+
                                    |
                                   SimpleResultSetStore

Known Subclasses:
  postgres.PostgresResultSetStore, BdbResultSetStore

Instance Methods

__init__(self, session, parent, config) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_verifyDefault(self, type, value)
generate_id(self)
Inherited from `baseObjects.ResultSetStore`: `create_resultSet`, `delete_resultSet`, `fetch_resultSet`, `fetch_resultSetList`, `store_resultSet` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

storeHash |
storeHashReverse |
databaseHash |
databaseHashReverse |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, parent, config) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### _verifyDefault(self, type, value) | source code
Overrides: configParser.C3Object._verifyDefault

### generate_id(self) | source code

Class Variable Details

    ### storeHash Value:
        {}

    ### storeHashReverse Value:
        {}

    ### databaseHash Value:
        {}

    ### databaseHashReverse Value:
        {}